#!/usr/bin/env node

/**
 * Module dependencies.
 */
const fs = require('fs');
const http = require('http');
const debug = require('debug')('procoder-watcher');
const app = require('../app');
const util = require('../libs/util');
const {iterate} = require('../libs/log');

const config = util.config();

/**
 * Get port from environment and store in Express.
 */
app.set('port', config.port);

/**
 * Create HTTP server.
 */
const server = http.createServer(app);

if (!fs.existsSync(config.logDir)) {
  throw new Error('Invalid LOG_PATH');
}

/**
 * Listen on provided port, on all network interfaces.
 */
server.listen(config.port);
server.on('error', onError);
server.on('listening', onListening);

/**
 * Event listener for HTTP server "error" event.
 */
function onError(error) {
  if (error.syscall !== 'listen') {
    throw error;
  }

  const bind = typeof config.port === 'string' ? 'Pipe ' + config.port : 'Port ' + config.port;

  // handle specific listen errors with friendly messages
  switch (error.code) {
    case 'EACCES':
      console.error(bind + ' requires elevated privileges');
      process.exit(1);
      break;
    case 'EADDRINUSE':
      console.error(bind + ' is already in use');
      process.exit(1);
      break;
    default:
      throw error;
  }
}

/**
 * Event listener for HTTP server "listening" event.
 */
function onListening() {
  const addr = server.address();
  const bind = typeof addr === 'string' ? 'pipe ' + addr : 'port ' + addr.port;
  debug(`Server started. port=${bind}, INTERVAL=${config.interval}, LOG_PATH=${config.logDir}`);

  // Start iteration
  setInterval(() => {
    iterate(config.logDir);
  }, config.interval);
}
